package br.com.bfisica.util;

import org.springframework.context.annotation.Bean;

import br.com.bfisica.controller.PersonController;
import br.com.bfisica.controller.spring.PersonControllerSpring;
import br.com.bfisica.dao.PersonDAO;
import br.com.bfisica.dao.hibernate.PersonDAOHibernate;
import br.com.bfisica.entity.Person;

/**
 * 
 * @author Sandro Boschetti
 * This class is intended for Spring configuration programmatically.
 * Using this class with AnnotationConfigApplicationContext as follows:
 * 
 * AnnotationConfigApplicationContext ctx = new AnnotationConfigApplicationContext(SpringSrBConfig.class);
 * PersonController personController = ctx.getBean(PersonController.class);
 * 
 * As there is a dao object in the controller class, it is necessary to annotate it with @Autowired:
 * 	@Autowired
 *  private PersonDAO personDAO;
 *
 */


// For some reason, it was not necessary to put the @Configuration annotation here
public class SpringSrBConfig {
	
	@Bean
	public PersonDAO personDAO(){
		return new PersonDAOHibernate();
	}
	
	@Bean
	public PersonController personController(){
		return new PersonControllerSpring();
	}

	// For now this method is only for test proposal
	@Bean
	public Person person(){
		Person person = new Person();
		person.setId(10);
		person.setName("Teste");
		return person;
	}

}
